@@ -275,7 +275,10 @@ gdk_pixmap_create_from_data (GdkDrawable    *drawable,
 {
   GdkDrawable *source_drawable;
 
-  source_drawable = _gdk_drawable_get_source_drawable (drawable);
+  if (drawable)
+    source_drawable = _gdk_drawable_get_source_drawable (drawable);
+  else
+    source_drawable = NULL;
   return _gdk_pixmap_create_from_data (source_drawable,
                                        data, width, height,
                                        depth, fg,bg);
@@ -689,6 +692,11 @@ gdk_pixmap_colormap_new_from_pixbuf (GdkColormap    *colormap,
  * Create a pixmap from a XPM file using a particular colormap.
  *
  * Returns: (transfer none): the #GdkPixmap.
+ *
+ * Deprecated: 2.22: Use a #GdkPixbuf instead. You can use
+ * gdk_pixbuf_new_from_file() to create it.
+ * If you must use a pixmap, use gdk_pixmap_new() to
+ * create it and Cairo to draw the pixbuf onto it.
  */
 GdkPixmap*
 gdk_pixmap_colormap_create_from_xpm (GdkDrawable    *drawable,
@@ -733,6 +741,11 @@ gdk_pixmap_colormap_create_from_xpm (GdkDrawable    *drawable,
  * Create a pixmap from a XPM file.
  *
  * Returns: (transfer none): the #GdkPixmap
+ *
+ * Deprecated: 2.22: Use a #GdkPixbuf instead. You can use
+ * gdk_pixbuf_new_from_file() to create it.
+ * If you must use a pixmap, use gdk_pixmap_new() to
+ * create it and Cairo to draw the pixbuf onto it.
  */
 GdkPixmap*
 gdk_pixmap_create_from_xpm (GdkDrawable    *drawable,
@@ -747,26 +760,33 @@ gdk_pixmap_create_from_xpm (GdkDrawable    *drawable,
 /**
  * gdk_pixmap_colormap_create_from_xpm_d:
  * @drawable: a #GdkDrawable, used to determine default values
- * for the new pixmap. Can be %NULL if @colormap is given.
+ *     for the new pixmap. Can be %NULL if @colormap is given.
  * @colormap: the #GdkColormap that the new pixmap will be use.
- * If omitted, the colormap for @window will be used.
+ *     If omitted, the colormap for @window will be used.
  * @mask: a pointer to a place to store a bitmap representing
- * the transparency mask of the XPM file. Can be %NULL,
- * in which case transparency will be ignored.
+ *     the transparency mask of the XPM file. Can be %NULL,
+ *     in which case transparency will be ignored.
  * @transparent_color: the color to be used for the pixels
- * that are transparent in the input file. Can be %NULL,
- * in which case a default color will be used.
+ *     that are transparent in the input file. Can be %NULL,
+ *     in which case a default color will be used.
  * @data: Pointer to a string containing the XPM data.
  *
  * Create a pixmap from data in XPM format using a particular
  * colormap.
+ *
+ * Returns: (transfer none): the #GdkPixmap.
+ *
+ * Deprecated: 2.22: Use a #GdkPixbuf instead. You can use
+ * gdk_pixbuf_new_from_xpm_data() to create it.
+ * If you must use a pixmap, use gdk_pixmap_new() to
+ * create it and Cairo to draw the pixbuf onto it.
  */
 GdkPixmap*
-gdk_pixmap_colormap_create_from_xpm_d (GdkDrawable    *drawable,
-				       GdkColormap    *colormap,
-				       GdkBitmap     **mask,
-				       const GdkColor *transparent_color,
-				       gchar         **data)
+gdk_pixmap_colormap_create_from_xpm_d (GdkDrawable     *drawable,
+				       GdkColormap     *colormap,
+				       GdkBitmap      **mask,
+				       const GdkColor  *transparent_color,
+				       gchar          **data)
 {
   GdkPixbuf *pixbuf;
   GdkPixmap *pixmap;
@@ -792,18 +812,23 @@ gdk_pixmap_colormap_create_from_xpm_d (GdkDrawable    *drawable,
 /**
  * gdk_pixmap_create_from_xpm_d:
  * @drawable: a #GdkDrawable, used to determine default values
- * for the new pixmap.
+ *     for the new pixmap.
  * @mask: (out): Pointer to a place to store a bitmap representing
- * the transparency mask of the XPM file. Can be %NULL,
- * in which case transparency will be ignored.
+ *     the transparency mask of the XPM file. Can be %NULL,
+ *     in which case transparency will be ignored.
  * @transparent_color: This color will be used for the pixels
- * that are transparent in the input file. Can be %NULL
- * in which case a default color will be used.
+ *     that are transparent in the input file. Can be %NULL
+ *     in which case a default color will be used.
  * @data: Pointer to a string containing the XPM data.
  *
  * Create a pixmap from data in XPM format.
  *
  * Returns: (transfer none): the #GdkPixmap.
+ *
+ * Deprecated: 2.22: Use a #GdkPixbuf instead. You can use
+ * gdk_pixbuf_new_from_xpm_data() to create it.
+ * If you must use a pixmap, use gdk_pixmap_new() to
+ * create it and Cairo to draw the pixbuf onto it.
  */
 GdkPixmap*
 gdk_pixmap_create_from_xpm_d (GdkDrawable    *drawable,
